# arpes.endstations.plugin.igor\_export module

**class arpes.endstations.plugin.igor\_export.IgorExportEndstation**

> Bases: `arpes.endstations.SESEndstation`
> 
> The Igor Export “Endstation” for ARPES data
> 
> `ALIASES = ['igor', 'igor-export']`
> 
> `PRINCIPAL_NAME = 'Igor'`
> 
> `RENAME_KEYS = {}`
> 
> **load\_SES\_h5(scan\_desc: dict = None,
> robust\_dimension\_labels=False,**kwargs)\*\*
> 
> > Imports an hdf5 dataset exported from Igor that was originally
> > generated by a Scienta spectrometer in the SESb format. In order to
> > understand the structure of these files have a look at Conrad’s
> > saveSESDataset in Igor Pro.
> > 
> >   - Parameters  
> >     **scan\_desc** – Dictionary with extra information to attach to
> >     the xr.Dataset, must contain the location
> > 
> > of the file :return: xr.Dataset
> 
> **load\_single\_frame(frame\_path: str = None, scan\_desc: dict =
> None,**kwargs)\*\*
